@@ -14,6 +14,7 @@ from stac_pydantic.version import STAC_VERSION
 from stac_fastapi.types import stac as stac_types
 from stac_fastapi.types.conformance import BASE_CONFORMANCE_CLASSES
 from stac_fastapi.types.extension import ApiExtension
+from stac_fastapi.types.search import BaseSearchPostRequest
 from stac_fastapi.types.stac import Conformance
 
 NumType = Union[float, int]
@@ -28,7 +29,7 @@ class BaseTransactionsClient(abc.ABC):
     def create_item(self, item: stac_types.Item, **kwargs) -> stac_types.Item:
         """Create a new item.
 
-        Called with `POST /collections/{collectionId}/items`.
+        Called with `POST /collections/{collection_id}/items`.
 
         Args:
             item: the item
@@ -43,7 +44,7 @@ class BaseTransactionsClient(abc.ABC):
     def update_item(self, item: stac_types.Item, **kwargs) -> stac_types.Item:
         """Perform a complete update on an existing item.
 
-        Called with `PUT /collections/{collectionId}/items`. It is expected that this item already exists.  The update
+        Called with `PUT /collections/{collection_id}/items`. It is expected that this item already exists.  The update
         should do a diff against the saved item and perform any necessary updates.  Partial updates are not supported
         by the transactions extension.
 
@@ -61,7 +62,7 @@ class BaseTransactionsClient(abc.ABC):
     ) -> stac_types.Item:
         """Delete an item from a collection.
 
-        Called with `DELETE /collections/{collectionId}/items/{itemId}`
+        Called with `DELETE /collections/{collection_id}/items/{item_id}`
 
         Args:
             item_id: id of the item.
@@ -110,7 +111,7 @@ class BaseTransactionsClient(abc.ABC):
     def delete_collection(self, collection_id: str, **kwargs) -> stac_types.Collection:
         """Delete a collection.
 
-        Called with `DELETE /collections/{collectionId}`
+        Called with `DELETE /collections/{collection_id}`
 
         Args:
             collection_id: id of the collection.
@@ -129,7 +130,7 @@ class AsyncBaseTransactionsClient(abc.ABC):
     async def create_item(self, item: stac_types.Item, **kwargs) -> stac_types.Item:
         """Create a new item.
 
-        Called with `POST /collections/{collectionId}/items`.
+        Called with `POST /collections/{collection_id}/items`.
 
         Args:
             item: the item
@@ -144,7 +145,7 @@ class AsyncBaseTransactionsClient(abc.ABC):
     async def update_item(self, item: stac_types.Item, **kwargs) -> stac_types.Item:
         """Perform a complete update on an existing item.
 
-        Called with `PUT /collections/{collectionId}/items`. It is expected that this item already exists.  The update
+        Called with `PUT /collections/{collection_id}/items`. It is expected that this item already exists.  The update
         should do a diff against the saved item and perform any necessary updates.  Partial updates are not supported
         by the transactions extension.
 
@@ -162,7 +163,7 @@ class AsyncBaseTransactionsClient(abc.ABC):
     ) -> stac_types.Item:
         """Delete an item from a collection.
 
-        Called with `DELETE /collections/{collectionId}/items/{itemId}`
+        Called with `DELETE /collections/{collection_id}/items/{item_id}`
 
         Args:
             item_id: id of the item.
@@ -213,7 +214,7 @@ class AsyncBaseTransactionsClient(abc.ABC):
     ) -> stac_types.Collection:
         """Delete a collection.
 
-        Called with `DELETE /collections/{collectionId}`
+        Called with `DELETE /collections/{collection_id}`
 
         Args:
             collection_id: id of the collection.
@@ -262,12 +263,6 @@ class LandingPageMixin(abc.ABC):
                     "type": MimeTypes.json,
                     "href": urljoin(base_url, "collections"),
                 },
-                {
-                    "rel": Relations.docs.value,
-                    "type": MimeTypes.json,
-                    "title": "OpenAPI docs",
-                    "href": urljoin(base_url, "docs"),
-                },
                 {
                     "rel": Relations.conformance.value,
                     "type": MimeTypes.json,
@@ -306,6 +301,7 @@ class BaseCoreClient(LandingPageMixin, abc.ABC):
         factory=lambda: BASE_CONFORMANCE_CLASSES
     )
     extensions: List[ApiExtension] = attr.ib(default=attr.Factory(list))
+    post_request_model = attr.ib(default=BaseSearchPostRequest)
 
     def conformance_classes(self) -> List[str]:
         """Generate conformance classes by adding extension conformance to base conformance classes."""
@@ -373,6 +369,17 @@ class BaseCoreClient(LandingPageMixin, abc.ABC):
                 "href": urljoin(base_url, request.app.openapi_url.lstrip("/")),
             }
         )
+
+        # Add human readable service-doc
+        landing_page["links"].append(
+            {
+                "rel": "service-doc",
+                "type": "text/html",
+                "title": "OpenAPI service documentation",
+                "href": urljoin(base_url, request.app.docs_url.lstrip("/")),
+            }
+        )
+
         return landing_page
 
     def conformance(self, **kwargs) -> stac_types.Conformance:
@@ -428,7 +435,7 @@ class BaseCoreClient(LandingPageMixin, abc.ABC):
     def get_item(self, item_id: str, collection_id: str, **kwargs) -> stac_types.Item:
         """Get item by id.
 
-        Called with `GET /collections/{collectionId}/items/{itemId}`.
+        Called with `GET /collections/{collection_id}/items/{item_id}`.
 
         Args:
             item_id: Id of the item.
@@ -454,7 +461,7 @@ class BaseCoreClient(LandingPageMixin, abc.ABC):
     def get_collection(self, collection_id: str, **kwargs) -> stac_types.Collection:
         """Get collection by id.
 
-        Called with `GET /collections/{collectionId}`.
+        Called with `GET /collections/{collection_id}`.
 
         Args:
             collection_id: Id of the collection.
@@ -470,7 +477,7 @@ class BaseCoreClient(LandingPageMixin, abc.ABC):
     ) -> stac_types.ItemCollection:
         """Get all items from a specific collection.
 
-        Called with `GET /collections/{collectionId}/items`
+        Called with `GET /collections/{collection_id}/items`
 
         Args:
             collection_id: id of the collection.
@@ -495,6 +502,7 @@ class AsyncBaseCoreClient(LandingPageMixin, abc.ABC):
         factory=lambda: BASE_CONFORMANCE_CLASSES
     )
     extensions: List[ApiExtension] = attr.ib(default=attr.Factory(list))
+    post_request_model = attr.ib(default=BaseSearchPostRequest)
 
     def conformance_classes(self) -> List[str]:
         """Generate conformance classes by adding extension conformance to base conformance classes."""
@@ -549,6 +557,16 @@ class AsyncBaseCoreClient(LandingPageMixin, abc.ABC):
             }
         )
 
+        # Add human readable service-doc
+        landing_page["links"].append(
+            {
+                "rel": "service-doc",
+                "type": "text/html",
+                "title": "OpenAPI service documentation",
+                "href": urljoin(base_url, request.app.docs_url.lstrip("/")),
+            }
+        )
+
         return landing_page
 
     async def conformance(self, **kwargs) -> stac_types.Conformance:
@@ -606,7 +624,7 @@ class AsyncBaseCoreClient(LandingPageMixin, abc.ABC):
     ) -> stac_types.Item:
         """Get item by id.
 
-        Called with `GET /collections/{collectionId}/items/{itemId}`.
+        Called with `GET /collections/{collection_id}/items/{item_id}`.
 
         Args:
             item_id: Id of the item.
@@ -634,7 +652,7 @@ class AsyncBaseCoreClient(LandingPageMixin, abc.ABC):
     ) -> stac_types.Collection:
         """Get collection by id.
 
-        Called with `GET /collections/{collectionId}`.
+        Called with `GET /collections/{collection_id}`.
 
         Args:
             collection_id: Id of the collection.
@@ -650,7 +668,7 @@ class AsyncBaseCoreClient(LandingPageMixin, abc.ABC):
     ) -> stac_types.ItemCollection:
         """Get all items from a specific collection.
 
-        Called with `GET /collections/{collectionId}/items`
+        Called with `GET /collections/{collection_id}/items`
 
         Args:
             collection_id: id of the collection.
